==> haskell-uri-bytestring-0.3.2.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.0
id: uri-bytestring-0.3.2.0-4IJzH8SCCoSHY4NuWBoS46
key: uri-bytestring-0.3.2.0-4IJzH8SCCoSHY4NuWBoS46
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: 698018e6f04c1f6eb987bdb01bad2472
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/uri-bytestring-0.3.2.0
hs-libraries: HSuri-bytestring-0.3.2.0-4IJzH8SCCoSHY4NuWBoS46
depends:
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    bytestring-0.10.8.2 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    template-haskell-2.13.0.0
    th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc containers-0.5.11.0
abi-depends: attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc=d113af445dde7da2fec2ce14d3c5ba79
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.2.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.0
id: uri-bytestring-0.3.2.0-7bZ8f3rvdyg8tUo2SDrlCV
key: uri-bytestring-0.3.2.0-7bZ8f3rvdyg8tUo2SDrlCV
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: be15da4e55377ea808a0fd459861e4f3
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/uri-bytestring-0.3.2.0
hs-libraries: HSuri-bytestring-0.3.2.0-7bZ8f3rvdyg8tUo2SDrlCV
depends:
    attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ base-4.11.1.0
    bytestring-0.10.8.2 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    template-haskell-2.13.0.0
    th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc containers-0.5.11.0
abi-depends: attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ=5fc61cc528c94bde8145f6cbd8ed3b00
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc=d113af445dde7da2fec2ce14d3c5ba79
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
